@@ -1,4 +1,6 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+import warnings
+from Bio import BiopythonWarning
+warnings.simplefilter('ignore', BiopythonWarning)
 
 from .core.abstar import run, run_standalone, main, parse_arguments, validate_args
 from .preprocess import fastqc, adapter_trim, quality_trim
